==> kdebase-3.0.1.tar.bz2: kdebase-3.0.1/kicker/ui/removespecialbutton_mnu.h <==
/*****************************************************************

Copyright (c) 2001 Matthias Elter <elter@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef __removespecialbutton_mnu_h__
#define __removespecialbutton_mnu_h__

#include <qptrlist.h>
#include <qpopupmenu.h>

#include "appletinfo.h"

class ContainerArea;
class BaseContainer;

class PanelRemoveSpecialButtonMenu : public QPopupMenu
{
    Q_OBJECT

public:
    PanelRemoveSpecialButtonMenu( ContainerArea *cArea, QWidget *parent=0, const char *name=0 );
    ~PanelRemoveSpecialButtonMenu();

protected slots:
    void slotExec( int id );
    void slotAboutToShow();
    void slotRemoveAll();

private:
    QPtrList<BaseContainer> 	containers;
    ContainerArea*		containerArea;
};

#endif

==> kdebase-3.4.2.tar.bz2: kdebase-3.4.2/kicker/ui/removespecialbutton_mnu.h <==
/*****************************************************************

Copyright (c) 2001 Matthias Elter <elter@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef __removespecialbutton_mnu_h__
#define __removespecialbutton_mnu_h__

#include <qptrlist.h>
#include <qpopupmenu.h>

#include "appletinfo.h"

class ContainerArea;
class BaseContainer;

class PanelRemoveSpecialButtonMenu : public QPopupMenu
{
    Q_OBJECT

public:
    PanelRemoveSpecialButtonMenu( ContainerArea *cArea, QWidget *parent=0, const char *name=0 );
    ~PanelRemoveSpecialButtonMenu();

protected slots:
    void slotExec( int id );
    void slotAboutToShow();
    void slotRemoveAll();

private:
    QPtrList<BaseContainer> m_containers;
    ContainerArea* m_containerArea;
};

#endif
